Struct Smcr
#[repr(transparent)]pub struct Smcr(pub u32);Expand description
RTC secure mode control register
Tuple Fields
0: u32Implementations
impl Smcr
impl Smcr
pub const fn set_alrdprot(&mut self, n: usize, val: bool)
pub const fn set_alrdprot(&mut self, n: usize, val: bool)
Alarm x protection
pub const fn set_wutdprot(&mut self, val: bool)
pub const fn set_wutdprot(&mut self, val: bool)
Wakeup timer protection
pub const fn set_tsdprot(&mut self, val: bool)
pub const fn set_tsdprot(&mut self, val: bool)
Timestamp protection
pub const fn caldprot(&self) -> bool
pub const fn caldprot(&self) -> bool
Shift register, daylight saving, calibration and reference clock protection
pub const fn set_caldprot(&mut self, val: bool)
pub const fn set_caldprot(&mut self, val: bool)
Shift register, daylight saving, calibration and reference clock protection
pub const fn set_initdprot(&mut self, val: bool)
pub const fn set_initdprot(&mut self, val: bool)
Initialization protection
pub const fn set_decprot(&mut self, val: bool)
pub const fn set_decprot(&mut self, val: bool)
RTC global protection